Karim Jerbi
c2d22e580e
perf(scene): optimize model_space_extents calculation with direct scalar reduction
Replace nested iterator chain (wires.iter().flat_map(...).chain(mesh_points).filter(...)) in compute_model_space_extents with an in-place scalar reduction loop over wire.key_vertices and mesh bounding boxes.
Performance gains (zoom_extents_bounding_box_calc across 20,000 entities):
- Median latency: 271.0 µs -> 224.0 µs (-17.3% latency reduction)
- Min latency: 207.0 µs
- Throughput: 89.29M entities/s
Testing:
- Added model_space_extents_mixed_entities_accuracy unit test
- All 8 scene::layout_cache_tests pass
2026-09-12 16:09:29 +01:00
..
2026-09-12 16:19:41 +03:00
2026-09-07 19:10:55 +03:00
2026-09-12 14:53:37 +03:00
2026-09-12 16:19:40 +03:00
2026-09-12 14:53:37 +03:00
2026-09-05 02:13:20 +03:00
2026-09-12 16:09:29 +01:00
2026-09-11 20:38:00 +03:00
2026-09-12 16:19:41 +03:00
2026-09-12 16:19:40 +03:00
2026-09-11 20:58:37 +03:00
2026-09-05 02:13:20 +03:00
2026-09-11 20:58:37 +03:00
2026-09-08 23:59:13 +03:00
2026-09-12 16:19:41 +03:00
2026-09-08 13:52:18 +03:00
2026-09-09 01:01:44 +03:00
2026-09-09 13:10:21 +03:00
2026-09-05 02:13:20 +03:00
2026-09-04 20:26:29 +03:00
2026-09-10 16:07:05 +03:00
2026-09-09 13:09:18 +03:00
2026-09-05 02:13:20 +03:00